// src/loaders/css-loader.ts
import { extname } from "path";
import { readFileSync } from "fs";

// src/util.ts
import createDebugger from "debug";
import tailwind from "tailwindcss/lib/processTailwindFeatures";
import getModuleDependencies from "tailwindcss/lib/lib/getModuleDependencies";
import resolveConfig from "tailwindcss/resolveConfig";
import normalizePath from "normalize-path";
import fastGlob from "fast-glob";

// src/devtools/server.ts
import { getPort } from "get-port-please";
import createServer from "tailwind-config-viewer/server";

// src/constants.ts
var PLUGIN_NAME = "tailwindcss-webpack-plugin";
var COMPILE_ENTRY_PATH = new URL("./templates/_compile-entry_.js", import.meta.url).pathname;
var TAILWIND_ENTRY_PATH = new URL("./templates/_tailwind_.css", import.meta.url).pathname;
var DEVTOOLS_ENTRY_PATH = new URL("./templates/_tailwind-devtools_.js", import.meta.url).pathname;
var DEVTOOLS_LOADER_PATH = new URL("./loaders/devtools-loader.js", import.meta.url).pathname;
var CSS_LOADER_PATH = new URL("./loaders/css-loader.js", import.meta.url).pathname;

// src/util.ts
var debug = createDebugger(PLUGIN_NAME);
var isDev = () => process.env.NODE_ENV === "development";

// src/loaders/css-loader.ts
async function CssLoader(source) {
  this.cacheable(false);
  debug(`[css-loader]: transform ${this.resourcePath} start`);
  const callback = this.async();
  const { service, dirty } = this._compiler.$tailwind;
  await service.ensureInit();
  if (dirty.size && isDev()) {
    const { configFiles, files } = Array.from(dirty).reduce((map, file) => {
      file === "config-file" || service.configDependencies.has(file) ? map.configFiles.push(file) : map.files.push(file);
      return map;
    }, {
      configFiles: [],
      files: []
    });
    if (configFiles.length) {
      await service.refresh();
    } else {
      service.updateChangedContent(files.map((file) => {
        return {
          content: readFileSync(file, "utf8"),
          extension: extname(file).slice(1)
        };
      }));
    }
    dirty.clear();
  }
  try {
    const result = await service.transformCSS(source);
    debug(`[css-loader]: transform ${this.resourcePath} success`);
    callback(null, result.css);
  } catch (err) {
    debug(`[css-loader]: transform ${this.resourcePath} err: 
${err}`);
    callback(err, `${source}
/* Error: ${err}*/`);
  }
}
export {
  CssLoader as default
};
